@@ -1,3 +1,5 @@
+#include <R.h>
+#include <Rinternals.h>
 #include <stdlib.h> // for NULL
 #include <R_ext/Rdynload.h>
 
@@ -7,7 +9,12 @@
 
 /* .C calls */
 extern void lk_main(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
+extern SEXP RdistC(SEXP, SEXP);
 
+static const R_CallMethodDef CallEntries[] = {
+  {"RdistC",  (DL_FUNC) &RdistC, 2},
+  {NULL, NULL, 0}
+};
 static const R_CMethodDef CEntries[] = {
     {"lk_main", (DL_FUNC) &lk_main, 18},
     {NULL, NULL, 0}
@@ -15,6 +22,6 @@ static const R_CMethodDef CEntries[] = {
 
 void R_init_ltsk(DllInfo *dll)
 {
-    R_registerRoutines(dll, CEntries, NULL, NULL, NULL);
+    R_registerRoutines(dll, CEntries, CallEntries, NULL, NULL);
     R_useDynamicSymbols(dll, FALSE);
 }
